# Audit: {adr_id}

- ADR: `{adr_path}`
- Generated: {generated_ts}

## Attestation Record
{attestation_section}

## Gate Results (from ledger)
{gate_results_section}

## OBPI Completion Summary
{obpi_summary_section}

## Verification Results
{verification_results_section}

## Evidence Links
{evidence_links_section}
